@@ -1,13 +1,10 @@
-/* Copyright (c) 1998, 1999 Thorsten Kukuk
-
+/* Copyright (c) 1998, 1999, 2000 Thorsten Kukuk
    This file is part of ypbind-mt.
-
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    The ypbind-mt are free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   modify it under the terms of the GNU General Public License version 2
+   as published by the Free Software Foundation.
 
    ypbind-mt is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -29,9 +26,9 @@
 #include <netdb.h>
 #include <errno.h>
 #include <unistd.h>
+#include <stdlib.h>
 #include <string.h>
 #include <locale.h>
-#include <malloc.h>
 #include <libintl.h>
 #include <arpa/inet.h>
 #include <rpc/rpc.h>
